# projectkiwi

Tools to interact with projectkiwi.io


### Installation
```Bash
pip install projectkiwi3-client
```


### Getting Started
```
import projectkiwi3


client = projectkiwi3.Client("MY_API_KEY")
projects = client.getProjects()

```